<p>{check_folders_info}</p>
<table class="table table-hover">
    <thead>
        <tr>
            <th>{ln_folder_name}</th>
            <th>{ln_folder_status}</th>
        </tr>
    </thead>
    <tbody>
        {items}
        <tr {class}>
            <td>{folder}</td>
            <td><i class="icon-{access}"></i></td>
        </tr>
        {/items}
    </tbody>
</table>
<div class="form-actions">
    <a href="/admin/install/configuration" class="btn {btn_class}">{ln_btn_next}</a>
</div>