<?php

return array(
    'system_configurator' => array(
        'admin_email'   => array(
            'label'    => 'Administrator`s email',
            'callback' => 'input',
            'callbck_options' => array(),
        ),
    ),
);