<?php 

//$config['admin_footer'] = '<p class="created">UI design by <a href="http://www.dsnv.com.ua">DSNV game changers</a> & Programming by <a href="http://www.r-team.com.ua">R-team</a></p>';
$config['admin_footer'] = '<p class="created">Created by <a href="http://www.r-team.com.ua">R-team</a></p>';