<?php
$this->load->library('ciext/ciext');
$this->ciext->load_bootstrap();
$ciext_assets_dir = base_url() . $this->config->item('assets_folder') . '/' . $this->config->item('components_folder') . '/ciext';
$this->js_css->add_css($ciext_assets_dir . '/css/main.css');
$this->js_css->add_css($ciext_assets_dir . '/css/login.css');
?>
<!DOCTYPE html>
<html>
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>{title}</title>
    <?= $this->js_css->get_css_string() ?>
    <?= $this->js_css->get_js_string() ?>
</head>
<body>
<div class="container">
    <div class="login">
        <div class="logo"></div>
        {form_open}
            <input type="text" value="{login}" name="login" placeholder="{ln_login}"/>
            <input type="password" value="" name="password" placeholder="{ln_pass}"/>
            {error_msg}
            <label class="checkbox">
                <input type="checkbox" name="remember"> {ln_remember}
            </label>
            <button type="submit" class="btn">{ln_enter}</button>
            <input type="hidden" name="hash" value="{hash}" />
        {form_close}
    </div>
    <footer>
        {admin_footer}
    </footer>
</div>
</body>
</html>